SliverGridDelegateWithMaxCrossAxisExtentAndLoading class

Inheritance

Constructors

SliverGridDelegateWithMaxCrossAxisExtentAndLoading({required dynamic maxCrossAxisExtent, required int itemCount, dynamic mainAxisSpacing = 0.0, dynamic crossAxisSpacing = 0.0, dynamic childAspectRatio = 1.0})
const

Properties

childAspectRatio → double
The ratio of the cross-axis to the main-axis extent of each child.
finalinherited
crossAxisSpacing → double
The number of logical pixels between each child along the cross axis.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
itemCount → int
final
mainAxisExtent → double?
The extent of each tile in the main axis. If provided it would define the logical pixels taken by each tile in the main-axis.
finalinherited
mainAxisSpacing → double
The number of logical pixels between each child along the main axis.
finalinherited
maxCrossAxisExtent → double
The maximum extent of tiles in the cross axis.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getLayout(SliverConstraints constraints) → SliverGridLayout
Returns information about the size and position of the tiles in the grid.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRelayout(covariant SliverGridDelegateWithMaxCrossAxisExtent oldDelegate) → bool
Override this method to return true when the children need to be laid out.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited