SliverGridRegularTileLayoutAndLoading class

Inheritance

Constructors

SliverGridRegularTileLayoutAndLoading({required dynamic crossAxisCount, required dynamic mainAxisStride, required dynamic crossAxisStride, required dynamic childMainAxisExtent, required dynamic childCrossAxisExtent, required dynamic reverseCrossAxis, required double fullCrossAccessExtent, required int itemCount})
const

Properties

childCrossAxisExtent → double
The number of pixels from the leading edge of one tile to the trailing edge of the same tile in the cross axis.
finalinherited
childMainAxisExtent → double
The number of pixels from the leading edge of one tile to the trailing edge of the same tile in the main axis.
finalinherited
crossAxisCount → int
The number of children in the cross axis.
finalinherited
crossAxisStride → double
The number of pixels from the leading edge of one tile to the leading edge of the next tile in the cross axis.
finalinherited
fullCrossAccessExtent → double
final
hashCode → int
The hash code for this object.
no setterinherited
itemCount → int
final
mainAxisStride → double
The number of pixels from the leading edge of one tile to the leading edge of the next tile in the main axis.
finalinherited
reverseCrossAxis → bool
Whether the children should be placed in the opposite order of increasing coordinates in the cross axis.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

computeMaxScrollOffset(int childCount) → double
The scroll extent needed to fully display all the tiles if there are childCount children in total.
inherited
getGeometryForChildIndex(int index) → SliverGridGeometry
The size and position of the child with the given index.
override
getMaxChildIndexForScrollOffset(double scrollOffset) → int
The maximum child index that intersects with (or is before) this scroll offset.
inherited
getMinChildIndexForScrollOffset(double scrollOffset) → int
The minimum child index that intersects with (or is after) this scroll offset.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited